@@ -174,11 +174,11 @@ int ipkg_conf_init(ipkg_conf_t *conf, const args_t *args)
 
      /* if (!lists_dir ){*/
      if (strlen(lists_dir)<=1 ){
-        lists_dir = realloc(lists_dir,strlen(IPKG_CONF_LISTS_DIR));
+        lists_dir = realloc(lists_dir,strlen(IPKG_CONF_LISTS_DIR)+2);
         sprintf (lists_dir,"%s",IPKG_CONF_LISTS_DIR);
      }
 
-     pending_dir = malloc(strlen(lists_dir)+strlen("/pending")+2);
+     pending_dir = malloc(strlen(lists_dir)+strlen("/pending")+5);
      snprintf(pending_dir,strlen(lists_dir)+strlen("/pending") ,"%s%s",lists_dir,"/pending");
 
      conf->lists_dir = strdup(lists_dir);
@@ -558,12 +558,12 @@ static int ipkg_conf_parse_file(ipkg_conf_t *conf, const char *filename,
 	       nv_pair_list_append(tmp_dest_nv_pair_list, name, value);
 	  } else if (strcmp(type, "lists_dir") == 0) {
 	       *lists_dir = realloc(*lists_dir,strlen(value)+1);
-               sprintf (*lists_dir,"%s",value);
                if (*lists_dir == NULL) {
 		    ipkg_message(conf, IPKG_ERROR, "ERROR: Not enough memory\n");
 	            free(options);
 	            return EINVAL;
                }
+               sprintf (*lists_dir,"%s",value);
 	  } else if (strcmp(type, "arch") == 0) {
 	       ipkg_message(conf, IPKG_INFO, "supported arch %s priority (%s)\n", name, value);
 	       if (!value) {
